<?php
/*
Plugin Name: Covert Messenger
Description: Simple plugin that generates instant messenger styled ads on your blog, grabbing your readers attention and "forcing" them to click your links. <a href="http://covertmessenger.com/upgrade" target="_blank">Click here to upgrade to the Pro version</a>.
Version: 2.2
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins
Requires at least: 6.0
Tested up to: 6.0.1

Copyright 2022 IM Wealth Builders

*/

define('IMWB_CIM_VERSION', '2.2');
define('IMWB_CIM_FOLDER', 'covertmessenger');
define('IMWB_CIM_PREFIX', 'imwb_');

require_once(WP_PLUGIN_DIR.'/'.IMWB_CIM_FOLDER."/mobile-detect.php");

/**
 * This is where you add comments for your plugin class
 * @author John Merrick
 */
class IMWB_Covert_Messenger {

	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $templates = Array("Aim" => array("Small" => "AS.png", "Medium" => "AM.png"),
	                        "Facebook" => array("Small" => "FS.png", "Medium" => "FM.png", "Large" => "FL.gif"),
	                        "ICQ" => Array("Small" => "IS.png", "Medium" => "IM.png"),
	                        "MSN" => Array("Small" => "MS.png", "Medium" => "MM.png"),
	                        "Skype" => Array("Small" => "SS.png", "Medium" => "SM.png", "Large" => "SL.gif"),
	                        "Yahoo" => Array("Small" => "YS.png", "Medium" => "YM.png")
	                     	);
    var $update;
    var $mobble_detect;

	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function __construct() {

      $this->plugin_name = IMWB_CIM_PREFIX.IMWB_CIM_FOLDER;

   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

      $this->plugin_url = plugins_url(basename( dirname( __FILE__)));

   	if(is_admin()){
      	$this->setup_update_info();
      	add_action('wp_ajax_'.$this->plugin_name.'_clear_cookie', array(&$this, 'clear_cookie'));
   		add_action('admin_menu', array(&$this,'init_admin_menu'));
   	}
   	else {
  			add_action('init', array(&$this, 'init_styles'), 20);
   		add_action('wp_print_scripts', array(&$this, 'init_scripts'),20);
   		add_action('wp_head', array(&$this, 'load_script'));
   	}
	}

	//Returns an array of admin options
	function get_admin_options() {
		$adminOptions = array('active' => "N",
		                      'im_template' => 'AS.png',
		                      'im_url' => 'http://yourdomain.com',
		                      'im_show_delay' => '0',
		                      'im_hide_delay' => '0',
		                      'im_reshow_delay' => '0',
		                      'im_reshow_days' => '0',
		                      'show_samewindow' => "true",
		                      'where_shown' => 'E',
		                      'im_from_name' => 'From: Joe Blogs',
		                      'im_msg_text' => 'This is the message text',
		                      'show_tablet' => 'Y',
		                      'show_mobile' => 'Y');

		$devOptions = get_option($this->plugin_name."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}
		update_option($this->plugin_name."-AdminOptions", $adminOptions);
		return $adminOptions;
	}

	/**
	 * Loading the Admin side javascripts
	 * /scripts/admin_options_page.js from the plugin directory.
	 * @return void
	 */
	function init_admin_scripts() {
		// Only enqueue scripts on frontend.
		wp_enqueue_script('jquery');
      wp_enqueue_script('jquery-ui-dialog');
	   wp_enqueue_script('imwb_cim_admin_options_script', $this->plugin_url.'/scripts/admin_options_page.js', array('jquery'), IMWB_CIM_VERSION);
	   wp_enqueue_script($this->plugin_name . '-videopopup-script', $this->plugin_url.'/scripts/jquery.videopopup.min.js', 'jquery' );

  	   wp_localize_script('imwb_cim_admin_options_script', 'IMWB_CIM_Ajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'nonce' => wp_create_nonce( 'imwb_cim_clear_cookie_nonce' ), 'plugin_url' => $this->plugin_url ) );
	}

	/**
	 * Loading the front end javascripts
	 * /scripts/script.js from the plugin directory.
	 * @return void
	 */
	function init_scripts() {
      wp_enqueue_script('jquery');
      wp_enqueue_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/script.js', array('jquery'), IMWB_CIM_VERSION);
	}

	/**
	 * Loads the stylesheet for this plugin.
	 * @return void
	 */
	function init_styles() {
		wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/style.css', array(), IMWB_CIM_VERSION, 'all');
	}

   /**
    * Loads the admin options stylesheet for this plugin.
    * @return void
    */
   function init_admin_styles() {
   	wp_enqueue_style($this->plugin_name . '-stylesheet-admin', $this->plugin_url.'/styles/admin_options_page.css', array(), IMWB_CIM_VERSION, 'all');
   	wp_enqueue_style('jquery-style', 'http://code.jquery.com/ui/1.10.3/themes/redmond/jquery-ui.css');
   	$this->init_styles();
   }

	/**
	 * Adds a new admin menu and let's anyone that can manage options
	 * be able to use it.
	 * @return void
	 */
	function init_admin_menu() {
		// Add the menu page
		$view_hook_name = add_menu_page( 'Covert Messenger Admin Menu',
		    'Covert Messenger',
		    'manage_options',
		    $this->plugin_name . '-admin-menu',
		    array(&$this, 'main_menu_page'),
		    'dashicons-testimonial');

		add_action( 'admin_print_styles-' . $view_hook_name, array(&$this, 'init_admin_styles'));
   	add_action( 'admin_print_scripts-' .$view_hook_name, array(&$this, 'init_admin_scripts'));

		$view_hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert Messenger Settings', 'Settings', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this, 'main_menu_page'));

		add_action( 'admin_print_styles-' . $view_hook_name, array(&$this, 'init_admin_styles'));
   	add_action( 'admin_print_scripts-' .$view_hook_name, array(&$this, 'init_admin_scripts'));
	}

	/**
	 * This function will be executed when the admin page is to be loaded
	 * @return void
	 */
	function main_menu_page() {
		$devOptions = $this->get_admin_options();
		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}

	/**
	 * Function is_tablet
	 * For detecting tablet devices (needs work)
	 */
	function is_tablet() {
		return apply_filters( 'is_tablet', $this->mobble_detect->isTablet(), $this->mobble_detect );
	}

	/**
	 * Function is_mobile
	 * For detecting ANY mobile phone device
	 */
	function is_mobile() {

		$result = null;
		if ( $this->is_tablet() ) {
			$result = false;
		} else {
			$result = $this->mobble_detect->isMobile();
		}
		return apply_filters( 'is_mobile', $result, $this->mobble_detect );
	}

	/**
	 * Loads the front end scripts that runs the plugins
	 * @return void
	 */
	function load_script() {
		$devOptions = $this->get_admin_options();

      if($devOptions['active'] == "N")
         return;

      $useragent = isset( $_SERVER['HTTP_USER_AGENT'] ) ? $_SERVER['HTTP_USER_AGENT'] : "";
      $this->mobble_detect = new IMWB_Mobile_Detect();
      $this->mobble_detect->setDetectionType( 'extended' );

      if($devOptions['show_tablet'] == 'N' && $this->is_tablet()) return;
      if($devOptions['show_mobile'] == 'N' && $this->is_mobile()) return;

      if((isset($_COOKIE['imwb_cim_show']) && $_COOKIE['imwb_cim_show'] == 'N') || (isset($_COOKIE['imwb_cim_reshow']) && $_COOKIE['imwb_cim_reshow'] == 'N'))
      	return true;

	   // Make sure we should be shown on this page
	   if($devOptions['where_shown'] == "F" && !is_front_page())
	   	return true;

	   if(!is_admin()) {
?>
	<script type="text/javascript">
      jQuery(document).ready(function($) {

        var showTimer;
        var hideTimer;

        if(cimCookie('imwb_cim_show') == 'N')
           return;

         // $() will work as an alias for jQuery() inside of this function
        $("body").append('<div id="imwb_cabim_panel" class="imwb_cabim_style_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions['im_template']);?>"><img src="<?php echo $this->plugin_url."/tpl/".$devOptions['im_template'];?>"><div id="imwb_cabim_dialog_from"><?php echo $this->sanitize_text($devOptions['im_from_name']) ?></div><div id="imwb_cabim_dialog_text"><?php echo $this->sanitize_text($devOptions['im_msg_text']) ?></div><img id="imwb_cabim_panel_close_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions['im_template']);?>" src="<?php echo $this->plugin_url."/images/blank.png";?>"></div>');

        showTimer = setTimeout(imwb_show_cim, <?php echo $devOptions["im_show_delay"]*1000;?>);

        function imwb_show_cim() {

           $("#imwb_cabim_panel").slideDown('slow');

           <?php if($devOptions['im_hide_delay'] > 0) {  ?>
              hideTimer = setTimeout(imwb_hide_cim, <?php echo ($devOptions["im_hide_delay"]*1000);?>);
           <?php } ?>
        }

        function imwb_hide_cim() {

           $("#imwb_cabim_panel").slideUp('slow');

           <?php if($devOptions['im_reshow_delay'] > 0) {  ?>
              showTimer = setTimeout(imwb_show_cim, <?php echo ($devOptions["im_reshow_delay"]*1000);?>);
           <?php } ?>
        }

        $("#imwb_cabim_panel_close_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions['im_template']);?>").click(function(event) {

             clearTimeout(showTimer);
             clearTimeout(hideTimer);

             $("#imwb_cabim_panel").slideUp('slow');

             event.stopPropagation();

             cimCookie('imwb_cim_show', 'N', <?php echo ($devOptions["im_reshow_days"]*24);?>,'<?php echo COOKIEPATH;?>');
        });

        $("#imwb_cabim_panel").click(function() {

              $("#imwb_cabim_panel").hide();
              cimCookie('imwb_cim_show', 'N', <?php echo ($devOptions["im_reshow_days"]*24);?>,'<?php echo COOKIEPATH;?>');

           <?php if(!empty($devOptions["im_url"])) { ?>
             <?php if ($devOptions['show_samewindow'] == "true") { ?>
                window.location = '<?php echo $devOptions["im_url"];?>';
             <?php } else { ?>
                window.open("<?php echo $devOptions["im_url"];?>","_blank");
             <?php } ?>
           <?php } ?>
        });


      });

	</script>
<?php
      }
  	}

	function setup_update_info() {
	   // Include Update Class
	   require_once('imwb-plugin-update-checker-no-lic.php');
	   $gdd21ed = __FILE__;

	   $this->update=new ImwbPluginUpdateChecker_nolic($gdd21ed,'covertmessenger','plugin-update',true);
	}

	function sanitize_text($text) {

      $text = do_shortcode($text);
	   $text = preg_replace("/(\r\n|\r|\n)/", "<br>", $text);
	   $text = addslashes_gpc(stripslashes($text));

	   return $text;
	}

	// AJAX Functions
	function clear_cookie() {

   	$nonce = $_POST['nonce'];

      if ( ! wp_verify_nonce( $nonce, 'imwb_cim_clear_cookie_nonce' ) )
         die ( 'Busted!');

		setcookie('imwb_cim_show','Y',time()-8640000,COOKIEPATH);
		echo 'OK';

		die();
	}
}

/**
 * Register the plugin
 */
$IMWBCovertMessenger = null;

function run_covert_messenger() {
  global $IMWBCovertMessenger;
	$IMWBCovertMessenger = new IMWB_Covert_Messenger();
}
run_covert_messenger();
